==> kubernetes-model-gatewayapi-6.4.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPRouteFilterFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPRouteFilterFluent<A extends HTTPRouteFilterFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildExtensionRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalObjectReference getExtensionRef();
  public LocalObjectReference buildExtensionRef();
  public A withExtensionRef(LocalObjectReference extensionRef);
  public Boolean hasExtensionRef();
  public A withNewExtensionRef(String group,String kind,String name);
  public HTTPRouteFilterFluent.ExtensionRefNested<A> withNewExtensionRef();
  public HTTPRouteFilterFluent.ExtensionRefNested<A> withNewExtensionRefLike(LocalObjectReference item);
  public HTTPRouteFilterFluent.ExtensionRefNested<A> editExtensionRef();
  public HTTPRouteFilterFluent.ExtensionRefNested<A> editOrNewExtensionRef();
  public HTTPRouteFilterFluent.ExtensionRefNested<A> editOrNewExtensionRefLike(LocalObjectReference item);
  
  /**
   * This method has been deprecated, please use method buildRequestHeaderModifier instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPRequestHeaderFilter getRequestHeaderModifier();
  public HTTPRequestHeaderFilter buildRequestHeaderModifier();
  public A withRequestHeaderModifier(HTTPRequestHeaderFilter requestHeaderModifier);
  public Boolean hasRequestHeaderModifier();
  public HTTPRouteFilterFluent.RequestHeaderModifierNested<A> withNewRequestHeaderModifier();
  public HTTPRouteFilterFluent.RequestHeaderModifierNested<A> withNewRequestHeaderModifierLike(HTTPRequestHeaderFilter item);
  public HTTPRouteFilterFluent.RequestHeaderModifierNested<A> editRequestHeaderModifier();
  public HTTPRouteFilterFluent.RequestHeaderModifierNested<A> editOrNewRequestHeaderModifier();
  public HTTPRouteFilterFluent.RequestHeaderModifierNested<A> editOrNewRequestHeaderModifierLike(HTTPRequestHeaderFilter item);
  
  /**
   * This method has been deprecated, please use method buildRequestMirror instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPRequestMirrorFilter getRequestMirror();
  public HTTPRequestMirrorFilter buildRequestMirror();
  public A withRequestMirror(HTTPRequestMirrorFilter requestMirror);
  public Boolean hasRequestMirror();
  public HTTPRouteFilterFluent.RequestMirrorNested<A> withNewRequestMirror();
  public HTTPRouteFilterFluent.RequestMirrorNested<A> withNewRequestMirrorLike(HTTPRequestMirrorFilter item);
  public HTTPRouteFilterFluent.RequestMirrorNested<A> editRequestMirror();
  public HTTPRouteFilterFluent.RequestMirrorNested<A> editOrNewRequestMirror();
  public HTTPRouteFilterFluent.RequestMirrorNested<A> editOrNewRequestMirrorLike(HTTPRequestMirrorFilter item);
  
  /**
   * This method has been deprecated, please use method buildRequestRedirect instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPRequestRedirectFilter getRequestRedirect();
  public HTTPRequestRedirectFilter buildRequestRedirect();
  public A withRequestRedirect(HTTPRequestRedirectFilter requestRedirect);
  public Boolean hasRequestRedirect();
  public HTTPRouteFilterFluent.RequestRedirectNested<A> withNewRequestRedirect();
  public HTTPRouteFilterFluent.RequestRedirectNested<A> withNewRequestRedirectLike(HTTPRequestRedirectFilter item);
  public HTTPRouteFilterFluent.RequestRedirectNested<A> editRequestRedirect();
  public HTTPRouteFilterFluent.RequestRedirectNested<A> editOrNewRequestRedirect();
  public HTTPRouteFilterFluent.RequestRedirectNested<A> editOrNewRequestRedirectLike(HTTPRequestRedirectFilter item);
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  
  /**
   * This method has been deprecated, please use method buildUrlRewrite instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPURLRewriteFilter getUrlRewrite();
  public HTTPURLRewriteFilter buildUrlRewrite();
  public A withUrlRewrite(HTTPURLRewriteFilter urlRewrite);
  public Boolean hasUrlRewrite();
  public HTTPRouteFilterFluent.UrlRewriteNested<A> withNewUrlRewrite();
  public HTTPRouteFilterFluent.UrlRewriteNested<A> withNewUrlRewriteLike(HTTPURLRewriteFilter item);
  public HTTPRouteFilterFluent.UrlRewriteNested<A> editUrlRewrite();
  public HTTPRouteFilterFluent.UrlRewriteNested<A> editOrNewUrlRewrite();
  public HTTPRouteFilterFluent.UrlRewriteNested<A> editOrNewUrlRewriteLike(HTTPURLRewriteFilter item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ExtensionRefNested<N> extends Nested<N>,LocalObjectReferenceFluent<HTTPRouteFilterFluent.ExtensionRefNested<N>>{
    public N and();
    public N endExtensionRef();
    
  }
  public interface RequestHeaderModifierNested<N> extends Nested<N>,HTTPRequestHeaderFilterFluent<HTTPRouteFilterFluent.RequestHeaderModifierNested<N>>{
    public N and();
    public N endRequestHeaderModifier();
    
  }
  public interface RequestMirrorNested<N> extends Nested<N>,HTTPRequestMirrorFilterFluent<HTTPRouteFilterFluent.RequestMirrorNested<N>>{
    public N and();
    public N endRequestMirror();
    
  }
  public interface RequestRedirectNested<N> extends Nested<N>,HTTPRequestRedirectFilterFluent<HTTPRouteFilterFluent.RequestRedirectNested<N>>{
    public N and();
    public N endRequestRedirect();
    
  }
  public interface UrlRewriteNested<N> extends Nested<N>,HTTPURLRewriteFilterFluent<HTTPRouteFilterFluent.UrlRewriteNested<N>>{
    public N and();
    public N endUrlRewrite();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.6.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPRouteFilterFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPRouteFilterFluent<A extends HTTPRouteFilterFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildExtensionRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalObjectReference getExtensionRef();
  public LocalObjectReference buildExtensionRef();
  public A withExtensionRef(LocalObjectReference extensionRef);
  public Boolean hasExtensionRef();
  public A withNewExtensionRef(String group,String kind,String name);
  public HTTPRouteFilterFluent.ExtensionRefNested<A> withNewExtensionRef();
  public HTTPRouteFilterFluent.ExtensionRefNested<A> withNewExtensionRefLike(LocalObjectReference item);
  public HTTPRouteFilterFluent.ExtensionRefNested<A> editExtensionRef();
  public HTTPRouteFilterFluent.ExtensionRefNested<A> editOrNewExtensionRef();
  public HTTPRouteFilterFluent.ExtensionRefNested<A> editOrNewExtensionRefLike(LocalObjectReference item);
  
  /**
   * This method has been deprecated, please use method buildRequestHeaderModifier instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPHeaderFilter getRequestHeaderModifier();
  public HTTPHeaderFilter buildRequestHeaderModifier();
  public A withRequestHeaderModifier(HTTPHeaderFilter requestHeaderModifier);
  public Boolean hasRequestHeaderModifier();
  public HTTPRouteFilterFluent.RequestHeaderModifierNested<A> withNewRequestHeaderModifier();
  public HTTPRouteFilterFluent.RequestHeaderModifierNested<A> withNewRequestHeaderModifierLike(HTTPHeaderFilter item);
  public HTTPRouteFilterFluent.RequestHeaderModifierNested<A> editRequestHeaderModifier();
  public HTTPRouteFilterFluent.RequestHeaderModifierNested<A> editOrNewRequestHeaderModifier();
  public HTTPRouteFilterFluent.RequestHeaderModifierNested<A> editOrNewRequestHeaderModifierLike(HTTPHeaderFilter item);
  
  /**
   * This method has been deprecated, please use method buildRequestMirror instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPRequestMirrorFilter getRequestMirror();
  public HTTPRequestMirrorFilter buildRequestMirror();
  public A withRequestMirror(HTTPRequestMirrorFilter requestMirror);
  public Boolean hasRequestMirror();
  public HTTPRouteFilterFluent.RequestMirrorNested<A> withNewRequestMirror();
  public HTTPRouteFilterFluent.RequestMirrorNested<A> withNewRequestMirrorLike(HTTPRequestMirrorFilter item);
  public HTTPRouteFilterFluent.RequestMirrorNested<A> editRequestMirror();
  public HTTPRouteFilterFluent.RequestMirrorNested<A> editOrNewRequestMirror();
  public HTTPRouteFilterFluent.RequestMirrorNested<A> editOrNewRequestMirrorLike(HTTPRequestMirrorFilter item);
  
  /**
   * This method has been deprecated, please use method buildRequestRedirect instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPRequestRedirectFilter getRequestRedirect();
  public HTTPRequestRedirectFilter buildRequestRedirect();
  public A withRequestRedirect(HTTPRequestRedirectFilter requestRedirect);
  public Boolean hasRequestRedirect();
  public HTTPRouteFilterFluent.RequestRedirectNested<A> withNewRequestRedirect();
  public HTTPRouteFilterFluent.RequestRedirectNested<A> withNewRequestRedirectLike(HTTPRequestRedirectFilter item);
  public HTTPRouteFilterFluent.RequestRedirectNested<A> editRequestRedirect();
  public HTTPRouteFilterFluent.RequestRedirectNested<A> editOrNewRequestRedirect();
  public HTTPRouteFilterFluent.RequestRedirectNested<A> editOrNewRequestRedirectLike(HTTPRequestRedirectFilter item);
  
  /**
   * This method has been deprecated, please use method buildResponseHeaderModifier instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPHeaderFilter getResponseHeaderModifier();
  public HTTPHeaderFilter buildResponseHeaderModifier();
  public A withResponseHeaderModifier(HTTPHeaderFilter responseHeaderModifier);
  public Boolean hasResponseHeaderModifier();
  public HTTPRouteFilterFluent.ResponseHeaderModifierNested<A> withNewResponseHeaderModifier();
  public HTTPRouteFilterFluent.ResponseHeaderModifierNested<A> withNewResponseHeaderModifierLike(HTTPHeaderFilter item);
  public HTTPRouteFilterFluent.ResponseHeaderModifierNested<A> editResponseHeaderModifier();
  public HTTPRouteFilterFluent.ResponseHeaderModifierNested<A> editOrNewResponseHeaderModifier();
  public HTTPRouteFilterFluent.ResponseHeaderModifierNested<A> editOrNewResponseHeaderModifierLike(HTTPHeaderFilter item);
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  
  /**
   * This method has been deprecated, please use method buildUrlRewrite instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPURLRewriteFilter getUrlRewrite();
  public HTTPURLRewriteFilter buildUrlRewrite();
  public A withUrlRewrite(HTTPURLRewriteFilter urlRewrite);
  public Boolean hasUrlRewrite();
  public HTTPRouteFilterFluent.UrlRewriteNested<A> withNewUrlRewrite();
  public HTTPRouteFilterFluent.UrlRewriteNested<A> withNewUrlRewriteLike(HTTPURLRewriteFilter item);
  public HTTPRouteFilterFluent.UrlRewriteNested<A> editUrlRewrite();
  public HTTPRouteFilterFluent.UrlRewriteNested<A> editOrNewUrlRewrite();
  public HTTPRouteFilterFluent.UrlRewriteNested<A> editOrNewUrlRewriteLike(HTTPURLRewriteFilter item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ExtensionRefNested<N> extends Nested<N>,LocalObjectReferenceFluent<HTTPRouteFilterFluent.ExtensionRefNested<N>>{
    public N and();
    public N endExtensionRef();
    
  }
  public interface RequestHeaderModifierNested<N> extends Nested<N>,HTTPHeaderFilterFluent<HTTPRouteFilterFluent.RequestHeaderModifierNested<N>>{
    public N and();
    public N endRequestHeaderModifier();
    
  }
  public interface RequestMirrorNested<N> extends Nested<N>,HTTPRequestMirrorFilterFluent<HTTPRouteFilterFluent.RequestMirrorNested<N>>{
    public N and();
    public N endRequestMirror();
    
  }
  public interface RequestRedirectNested<N> extends Nested<N>,HTTPRequestRedirectFilterFluent<HTTPRouteFilterFluent.RequestRedirectNested<N>>{
    public N and();
    public N endRequestRedirect();
    
  }
  public interface ResponseHeaderModifierNested<N> extends Nested<N>,HTTPHeaderFilterFluent<HTTPRouteFilterFluent.ResponseHeaderModifierNested<N>>{
    public N and();
    public N endResponseHeaderModifier();
    
  }
  public interface UrlRewriteNested<N> extends Nested<N>,HTTPURLRewriteFilterFluent<HTTPRouteFilterFluent.UrlRewriteNested<N>>{
    public N and();
    public N endUrlRewrite();
    
  }
  
}
